@@ -44,8 +44,10 @@ module MiniMagick
     # @private
     attr_reader :name, :args
 
-    # @param whiny [Boolean] Whether to raise errors on exit codes different
-    #   than 0.
+    # @param name [String]
+    # @param options [Hash]
+    # @option options [Boolean] :whiny Whether to raise errors on non-zero
+    #   exit codes.
     # @example
     #   MiniMagick::Tool::Identify.new(whiny: false) do |identify|
     #     identify.help # returns exit status 1, which would otherwise throw an error
@@ -190,9 +192,15 @@ module MiniMagick
     #   end
     #   # executes `convert wand.gif \( wizard.gif -rotate 30 \) +append images.gif`
     #
-    def stack
+    def stack(*args)
       self << "("
-      yield self
+      args.each do |value|
+        case value
+        when Hash   then value.each { |key, value| send(key, *value) }
+        when String then self << value
+        end
+      end
+      yield self if block_given?
       self << ")"
     end
 
@@ -227,6 +235,7 @@ module MiniMagick
     ##
     # Define creator operator methods
     #
+    # @example
     #   mogrify = MiniMagick::Tool.new("mogrify")
     #   mogrify.canvas("khaki")
     #   mogrify.command.join(" ") #=> "mogrify canvas:khaki"
@@ -251,10 +260,11 @@ module MiniMagick
     ##
     # Any undefined method will be transformed into a CLI option
     #
+    # @example
     #   mogrify = MiniMagick::Tool.new("mogrify")
     #   mogrify.adaptive_blur("...")
     #   mogrify.foo_bar
-    #   mogrify.command.join(" ") "mogrify -adaptive-blur ... -foo-bar"
+    #   mogrify.command.join(" ") # => "mogrify -adaptive-blur ... -foo-bar"
     #
     def method_missing(name, *args)
       option = "-#{name.to_s.tr('_', '-')}"
